@@ -1,7 +1,8 @@
-/* $Id: common_handlers.h,v 1.3 2004/05/02 11:16:17 twogood Exp $ */
+/* $Id: common_handlers.h 2480 2006-06-15 13:09:40Z cerly $ */
 #ifndef __common_handlers_h__
 #define __common_handlers_h__
 
+#include <inttypes.h>
 #include <stdbool.h>
 #include <libmimedir.h>
 
@@ -21,5 +22,12 @@ bool on_mdir_line_location   (struct _Parser* p, mdir_line* line, void* cookie);
 bool on_mdir_line_description(struct _Parser* p, mdir_line* line, void* cookie);
 bool on_mdir_line_summary    (struct _Parser* p, mdir_line* line, void* cookie);
 
+#define REMINDER_RELATED_START 0
+#define REMINDER_RELATED_END   1
+
+void to_propval_trigger(struct _Parser* parser, mdir_line* line, uint8_t related_support);
+
+void to_icalendar_trigger(struct _Generator* generator, struct _CEPROPVAL* reminder_enabled, struct _CEPROPVAL* reminder_minutes, uint8_t related);
+
 #endif
 
